# Installation

PyMatching can be downloaded and installed from [PyPI](https://pypi.org/project/PanQEC/) with the command::

```bash
pip install panqec
```

To test that the installation worked, you can try starting the GUI locally:

```bash
panqec start-gui
```

Go to `localhost:5000` in your browser to view the web interface.

If instead you would like to install PanQEC from source, clone the repository and then use `pip` to install:

```bash
git clone https://github.com/panqec/panqec
pip install -e ./panqec
```

Refer to the tutorials section to get started using it.
